@@ -55,7 +55,7 @@ class BKTreeNode[ValueT]:
                 value=value_type(**node_input["value"]), value_type=value_type
             )
         for key, value in node_input["children"].items():
-            new_node.children[int(key)] = cls.from_dict(value)
+            new_node.children[int(key)] = cls.from_dict(value, value_type=value_type)
         return new_node
 
     def __len__(self):
